@@ -37,11 +37,6 @@
 
 using namespace KIO;
 
-static QString stylesheet;
-static QString header_background;
-static QString header_logo;
-
-
 /*************************************************************************
 * Common definitions of HTML fragments
 */
@@ -69,7 +64,7 @@ static const QString
             "<body>\n"));
 
 static QString close_html_head();
-static QString open_html_head(const QString& title, bool links)
+static QString open_html_head(const QString& title, bool links, AptProtocol const& config)
 {
 
   static const QString
@@ -77,19 +72,20 @@ static QString open_html_head(const QString& title, bool links)
               "<table class=\"header\" style=\"background-image: url(file:%1);\"\n"
                     "\t\tcellspacing=\"0\" cellpadding=\"0\">\n"
               "<tr>\n"
-              "\t<td class=\"logo\" %2><img src=\"file:%3\" alt=\"KDE on Debian\" style=\"border: 0px\" /></td>\n"
+              "\t<td class=\"logo\" %2><img src=\"file:%3\" alt=\"%4\" style=\"border: 0px\" /></td>\n"
               "\t<td class=\"header-title\">%4</td>\n");
 
   QString rowspan;
   if (links) rowspan = "rowspan=\"2\"";
   QString ret =
    html_head
-    .arg(stylesheet)
+    .arg(config.stylesheet())
     .arg(title)
    + html_head_table
-    .arg(header_background)
+    .arg(config.header_background())
     .arg(rowspan)
-    .arg(header_logo)
+    .arg(config.logo())
+    .arg(config.logo_alt())
     .arg(title);
 
   if (links)
@@ -174,7 +170,7 @@ static QString make_extform_cmd(bool ext_form, const KURL& query)
   url.addQueryItem("extended_form", cmd);
   url.setRef("extformcmd");
 
-  return
+  return 
     "<div class=\"command\" id=\"extformcmd\">\n"
     "\t<a href=\"" + url.htmlURL() + "\">[" + msg + "]</a>\n"
     "</div>\n";
@@ -183,11 +179,15 @@ static QString make_extform_cmd(bool ext_form, const KURL& query)
 /** Prints the HTML code for the query form */
 QString AptProtocol::make_html_form() const
 {
-  bool can_fsearch = false, online = false;
+  bool can_fsearch = false;
   bool ext_form = KGlobal::config() -> readBoolEntry("extended_form", true);
+  // Only in config-file. Needed for some dpkg-based distros that are not Debian
   can_fsearch = can_searchfile(true);
+
+  bool online = false;
+  bool online_form = KGlobal::config() -> readBoolEntry("online_form", true);
   if (m_pkgmanager)
-    online = (!m_internal) && ext_form && m_pkgmanager -> capabilities(PackageManager::ONLINE);
+    online = online_form && (!m_internal) && ext_form && m_pkgmanager -> capabilities(PackageManager::ONLINE);
 
   QString ret;
   QTextOStream stream(&ret);
@@ -225,9 +225,15 @@ AptProtocol::AptProtocol( const QCString &pool_socket, const QCString &app_socke
 
 {
   KStandardDirs* dirs = KGlobal::dirs();
-  stylesheet = dirs->findResource( "data", "kio_apt/kio_apt.css" );
-  header_logo = dirs->findResource( "data", "kio_apt/kdedeb_logo.png" );
-  header_background = dirs->findResource( "html", "en/common/headerbg.png" );
+  m_stylesheet = dirs->findResource( "data", "kio_apt/kio_apt.css" );
+
+  m_logo = dirs->findResource( "data", "kio_apt/" 
+          + KGlobal::config() -> readEntryUntranslated("logo", "kdedeb_logo.png" ) );
+
+  m_header_background = dirs->findResource( "data", "kio_apt/" 
+          + KGlobal::config() -> readEntryUntranslated("background", "headerbg.png" ) );
+
+  m_logo_alt = KGlobal::config() -> readEntryUntranslated("alt_tag", i18n("KDE on Debian") );
 
   connect(&m_process, SIGNAL(token(const QString&, const QString&)),
     this, SLOT(token_dispatch(const QString&, const QString&)));
@@ -247,6 +253,11 @@ AptProtocol::AptProtocol( const QCString &pool_socket, const QCString &app_socke
 
 AptProtocol::~AptProtocol() {}
 
+QString AptProtocol::stylesheet() const { return m_stylesheet; }
+QString AptProtocol::logo() const { return m_logo; }
+QString AptProtocol::logo_alt() const { return m_logo_alt; }
+QString AptProtocol::header_background() const { return m_header_background; }
+
 void AptProtocol::token_dispatch(const QString& name, const QString& val)
 {
   if (m_parser.get())
@@ -382,20 +393,23 @@ void AptProtocol::get ( const KURL& url )
   if (!opt.isNull())
   {
     bool ext_form = (opt != "0");
-    KConfig* config = KGlobal::config();
-    config -> writeEntry("extended_form", ext_form);
-    config -> sync();
+    KGlobal::config() -> writeEntry("extended_form", ext_form);
   }
 
+  // Enable install/remove/upgrade/...
   opt = read_option(options, "enable_actions", "1");
-  m_act = (opt == "1");
+  m_act = (opt != "0");
 
   opt = read_option(options, "enable_search", "1");
-  m_search = (opt == "1");
+  m_search = (opt != "0");
 
+  // Allow links outside of apt:/ hierarchy
   opt = read_option(options, "stay_internal", "0");
   m_internal = (opt == "1");
 
+  // Sync the config (must use kcfg sometime :p)
+  KGlobal::config() -> sync();
+
   if (command.isEmpty() || query.isEmpty())
   {
     // No query or no command, we go in help mode
@@ -437,7 +451,7 @@ void AptProtocol::help()
   QString buffer;
   QTextOStream stream(&buffer);
   stream
-        << open_html_head(i18n("Search Form"), false)
+        << open_html_head(i18n("Search Form"), false, *this)
         << make_html_form()
         << make_html_tail(QString::null, false);
   data(buffer);
@@ -459,7 +473,7 @@ void AptProtocol::search( const QString& query, const QueryOptions& /*options*/
 {
   mimeType("text/html");
 
-  data(open_html_head(i18n("Package search result for \"%1\"").arg(query), false));
+  data(open_html_head(i18n("Package search result for \"%1\"").arg(query), false, *this));
 
   m_parser.reset(new Parsers::Search);
   (*m_parser)(this, "begin", query);
@@ -537,13 +551,13 @@ void AptProtocol::show(const QString& package, const QueryOptions& options)
     if (can_list)
     {
       KURL url = buildURL("list", package);
-      s << open_html_head(i18n("Package description for \"%1\"").arg(package), true)
+      s << open_html_head(i18n("Package description for \"%1\"").arg(package), true, *this)
         <<   add_html_head_link(url.htmlURL(), i18n("List package files"), "")
         << close_html_head();
     }
     else
     {
-      s << open_html_head(i18n("Package description for \"%1\"").arg(package), false);
+      s << open_html_head(i18n("Package description for \"%1\"").arg(package), false, *this);
     }
     data(buffer);
   }
@@ -626,7 +640,7 @@ void AptProtocol::policy( const QString& query, const QueryOptions& /*options*/
 
   mimeType("text/html");
 
-  data( open_html_head(i18n("Apt policy for \"%1\"").arg(query), false) );
+  data( open_html_head(i18n("Apt policy for \"%1\"").arg(query), false, *this) );
 
   m_parser.reset(new Parsers::Policy(query, m_act));
   (*m_parser)(this, "begin", QString::null);
@@ -665,7 +679,7 @@ void AptProtocol::searchfile(const QString& query, const QueryOptions& /*options
   if (!can_searchfile(true)) return;
 
   mimeType("text/html");
-  data( open_html_head(i18n("File search for \"%1\"").arg(query), false) + html_dpkgs_begin );
+  data( open_html_head(i18n("File search for \"%1\"").arg(query), false, *this) + html_dpkgs_begin );
 
   m_parser.reset(new Parsers::FileSearch);
   (*m_parser)(this, "begin", QString::null);
@@ -708,7 +722,7 @@ void AptProtocol::listfiles(const QString& query, const QueryOptions& /*options*
   QString buffer;
   QTextOStream stream(&buffer);
   stream
-        << open_html_head(i18n("Files in \"%1\"").arg(query), true)
+        << open_html_head(i18n("Files in \"%1\"").arg(query), true, *this)
         <<   add_html_head_link(ret_url.htmlURL(), i18n("Show package info"), "")
         << close_html_head()
         << endl;
@@ -735,11 +749,12 @@ void AptProtocol::listfiles(const QString& query, const QueryOptions& /*options*
  * Go use online search services (like packages.debian.org for instance)
  */
 
-bool AptProtocol::can_online(int mode) const
-{
-  if (!m_pkgmanager) return false;
-  return m_pkgmanager -> capabilities(PackageManager::ONLINE | mode);
-}
+//bool AptProtocol::can_online(int mode) const
+//{
+////  if (!m_pkgmanager) return false;
+////  return m_pkgmanager -> capabilities(PackageManager::ONLINE | mode);
+//  return false;
+//}
 
 void AptProtocol::online(const QString& query, const QueryOptions& options)
 {
@@ -787,6 +802,8 @@ void AptProtocol::pkgmanager(const QString& query, const QueryOptions& options)
   else if (!dist.isEmpty())
     command += "/" + dist;
 
+  kdDebug(DEBUG_ZONE) << command << endl;
+
   mimeType("application/x-pkgmanager");
   data(command + "\n");
   data(QByteArray());
